@@ -26,6 +26,7 @@
 #include <config.h>
 #include "gnome-vfs-uri.h"
 
+#include "gnome-vfs-module.h"
 #include "gnome-vfs-private-utils.h"
 #include "gnome-vfs-transform.h"
 #include "gnome-vfs-utils.h"
@@ -309,7 +310,7 @@ set_uri_element (GnomeVFSURI *uri,
 	char *escaped_text;
 
 	if (text == NULL || len == 0) {
-		uri->text = NULL;
+		uri->text = g_strdup("/");;
 		return;
 	}
 
@@ -479,11 +480,13 @@ gnome_vfs_uri_new_private (const gchar *text_uri,
 	if (allow_transforms) {
 		trans = gnome_vfs_transform_get (method_string);
 		if (trans != NULL && trans->transform) {
-			GnomeVFSContext *context;
+			const GnomeVFSContext *context;
 			
-			context = gnome_vfs_context_new ();
-			(* trans->transform) (trans, method_scanner, &new_uri_string, context);
-			gnome_vfs_context_unref (context);
+			context = gnome_vfs_context_peek_current ();
+			(* trans->transform) (trans, 
+					      method_scanner, 
+					      &new_uri_string, 
+					      (GnomeVFSContext *) context);
 			if (new_uri_string != NULL) {
 				toplevel->urn = g_strdup (text_uri);
 				g_free (method_string);
@@ -800,7 +803,7 @@ make_full_uri_from_relative (const char *base_uri, const char *uri)
 /**
  * gnome_vfs_uri_resolve_relative
  * @base: The base URI.
- * @text_uri: A string representing a possibly relative URI reference
+ * @relative_reference: A string representing a possibly relative URI reference
  * 
  * Create a new URI from @relative_reference, relative to @base.
  *
@@ -936,7 +939,7 @@ gnome_vfs_uri_dup (const GnomeVFSURI *uri)
 /**
  * gnome_vfs_uri_append_string:
  * @uri: A GnomeVFSURI.
- * @uri_fragment_string: A piece of a URI (ie a fully escaped partial path)
+ * @uri_fragment: A piece of a URI (ie a fully escaped partial path)
  * 
  * Create a new URI obtained by appending @path to @uri.  This will take care
  * of adding an appropriate directory separator between the end of @uri and
@@ -946,7 +949,7 @@ gnome_vfs_uri_dup (const GnomeVFSURI *uri)
  **/
 GnomeVFSURI *
 gnome_vfs_uri_append_string (const GnomeVFSURI *uri,
-			     const gchar *uri_part_string)
+			     const gchar *uri_fragment)
 {
 	gchar *uri_string;
 	GnomeVFSURI *new_uri;
@@ -954,13 +957,13 @@ gnome_vfs_uri_append_string (const GnomeVFSURI *uri,
 	guint len;
 
 	g_return_val_if_fail (uri != NULL, NULL);
-	g_return_val_if_fail (uri_part_string != NULL, NULL);
+	g_return_val_if_fail (uri_fragment != NULL, NULL);
 
 	uri_string = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
 	len = strlen (uri_string);
 	if (len == 0) {
 		g_free (uri_string);
-		return gnome_vfs_uri_new (uri_part_string);
+		return gnome_vfs_uri_new (uri_fragment);
 	}
 
 	len--;
@@ -970,14 +973,14 @@ gnome_vfs_uri_append_string (const GnomeVFSURI *uri,
 
 	uri_string[len + 1] = '\0';
 
-	while (*uri_part_string == GNOME_VFS_URI_PATH_CHR) {
-		uri_part_string++;
+	while (*uri_fragment == GNOME_VFS_URI_PATH_CHR) {
+		uri_fragment++;
 	}
 
-	if (uri_part_string[0] != GNOME_VFS_URI_MAGIC_CHR) {
-		new_string = g_strconcat (uri_string, GNOME_VFS_URI_PATH_STR, uri_part_string, NULL);
+	if (uri_fragment[0] != GNOME_VFS_URI_MAGIC_CHR) {
+		new_string = g_strconcat (uri_string, GNOME_VFS_URI_PATH_STR, uri_fragment, NULL);
 	} else {
-		new_string = g_strconcat (uri_string, uri_part_string, NULL);
+		new_string = g_strconcat (uri_string, uri_fragment, NULL);
 	}
 	new_uri = gnome_vfs_uri_new (new_string);
 
@@ -1014,7 +1017,7 @@ gnome_vfs_uri_append_path (const GnomeVFSURI *uri,
 /**
  * gnome_vfs_uri_append_file_name:
  * @uri: A GnomeVFSURI.
- * @path: any "regular" file name (can include #, /, etc)
+ * @filename: any "regular" file name (can include #, /, etc)
  * 
  * Create a new URI obtained by appending @file_name to @uri.  This will take care
  * of adding an appropriate directory separator between the end of @uri and
@@ -1024,12 +1027,12 @@ gnome_vfs_uri_append_path (const GnomeVFSURI *uri,
  **/
 GnomeVFSURI *
 gnome_vfs_uri_append_file_name (const GnomeVFSURI *uri,
-				const gchar *file_name)
+				const gchar *filename)
 {
 	gchar *escaped_string;
 	GnomeVFSURI *new_uri;
 	
-	escaped_string = gnome_vfs_escape_string (file_name);
+	escaped_string = gnome_vfs_escape_string (filename);
 	new_uri = gnome_vfs_uri_append_string (uri, escaped_string);
 	g_free (escaped_string);
 	return new_uri;
@@ -1643,7 +1646,7 @@ gnome_vfs_uri_extract_dirname (const GnomeVFSURI *uri)
 
 	base = strrchr (uri->text, GNOME_VFS_URI_PATH_CHR);
 
-	if (base == NULL || base[1] == '\0') {
+	if (base == NULL || base == uri->text) {
 		return g_strdup (GNOME_VFS_URI_PATH_STR);
 	}
 
@@ -1750,6 +1753,16 @@ gnome_vfs_uri_extract_short_path_name (const GnomeVFSURI *uri)
 
 /* The following functions are useful for creating URI hash tables.  */
 
+/**
+ * gnome_vfs_uri_hequal:
+ * @a: a pointer to a GnomeVFSURI
+ * @b: a pointer to a GnomeVFSURI
+ *
+ * Function intended for use as a hash table "are these two items
+ * the same" comparison. Useful for creating a hash table of URIs.
+ *
+ * Return value: %TRUE if the URIs are the same
+ **/
 gint
 gnome_vfs_uri_hequal (gconstpointer a,
 		      gconstpointer b)
@@ -1757,6 +1770,15 @@ gnome_vfs_uri_hequal (gconstpointer a,
 	return gnome_vfs_uri_equal (a, b);
 }
 
+/**
+ * gnome_vfs_uri_hash:
+ * @p: a pointer to a GnomeVFSURI
+ *
+ * Creates an integer value from a GnomeVFSURI, appropriate
+ * for using as the key to a hash table entry.
+ *
+ * Return value: a hash key corresponding to @p
+ **/
 guint
 gnome_vfs_uri_hash (gconstpointer p)
 {
@@ -1796,6 +1818,14 @@ gnome_vfs_uri_hash (gconstpointer p)
 #undef HASH_NUMBER
 }
 
+/**
+ * gnome_vfs_uri_list_ref:
+ * @list: list of GnomeVFSURI elements
+ *
+ * Increments the reference count of the items in @list by one.
+ *
+ * Return value: @list
+ **/
 GList *
 gnome_vfs_uri_list_ref (GList *list)
 {
@@ -1803,6 +1833,16 @@ gnome_vfs_uri_list_ref (GList *list)
 	return list;
 }
 
+/**
+ * gnome_vfs_uri_list_unref:
+ * @list: list of GnomeVFSURI elements
+ *
+ * Decrements the reference count of the items in @list by one.
+ * Note that the list is *not freed* even if each member of the list
+ * is freed.
+ *
+ * Return value: @list
+ **/
 GList *
 gnome_vfs_uri_list_unref (GList *list)
 {
@@ -1810,12 +1850,28 @@ gnome_vfs_uri_list_unref (GList *list)
 	return list;
 }
 
+/**
+ * gnome_vfs_uri_list_copy:
+ * @list: list of GnomeVFSURI elements
+ *
+ * Creates a duplicate of @list, and references each member of
+ * that list.
+ *
+ * Return value: a newly referenced duplicate of @list
+ **/
 GList *
 gnome_vfs_uri_list_copy (GList *list)
 {
 	return g_list_copy (gnome_vfs_uri_list_ref (list));
 }
 
+/**
+ * gnome_vfs_uri_list_free:
+ * @list: list of GnomeVFSURI elements
+ *
+ * Decrements the reference count of each member of @list by one,
+ * and frees the list itself.
+ **/
 void
 gnome_vfs_uri_list_free (GList *list)
 {
@@ -1844,6 +1900,8 @@ is_uri_partial (const char *uri)
 
 /**
  * gnome_vfs_uri_make_full_from_relative:
+ * @base_uri: a string representing the base URI
+ * @relative_uri: a URI fragment/reference to be appended to @base_uri
  * 
  * Returns a full URI given a full base URI, and a secondary URI which may
  * be relative.
